@@ -1,8 +1,14 @@
 import os.path
-import fcntl
 import logging
 import sys
 
+try:
+    import fcntl
+
+    use_fcntl = True
+except:
+    use_fcntl = False
+
 logger = logging.getLogger("acm")
 
 
@@ -13,12 +19,12 @@ def read_file(base, key):
 
     try:
         if sys.version_info[0] == 3:
-            with open(file_path, "r+", newline="") as f:
-                fcntl.flock(f, fcntl.LOCK_EX)
+            with open(file_path, "r+", encoding="utf8", newline="") as f:
+                lock_file(f)
                 return f.read()
         else:
             with open(file_path, "r+") as f:
-                fcntl.flock(f, fcntl.LOCK_EX)
+                lock_file(f)
                 return f.read()
     except OSError:
         logger.exception("[read-file] read file failed, file path:%s" % file_path)
@@ -34,9 +40,10 @@ def save_file(base, key, content):
             logger.warning("[save-file] dir %s is already exist" % base)
 
     try:
-        with open(file_path, "w") as f:
-            fcntl.flock(f, fcntl.LOCK_EX)
-            f.write(content)
+        with open(file_path, "wb") as f:
+            lock_file(f)
+            f.write(content if type(content) == bytes else content.encode("utf8"))
+
     except OSError:
         logger.exception("[save-file] save file failed, file path:%s" % file_path)
 
@@ -47,3 +54,8 @@ def delete_file(base, key):
         os.remove(file_path)
     except OSError:
         logger.warning("[delete-file] file not exists, file path:%s" % file_path)
+
+
+def lock_file(f):
+    if use_fcntl:
+        fcntl.flock(f, fcntl.LOCK_EX)
